@@ -134,6 +134,16 @@ class BluexpressHandler:
             'listaCobrosContraEntregaCrearReq': xsd.SkipValue
         }
 
+        if hasattr(instance, 'sender'):
+            payload.update(
+                {
+                    'codigoRegionEmbalador': instance.sender.region.code,
+                    'codigoComunaEmbalador': instance.sender.commune.zone_code,
+                    'codigoLocalidadOrigen': instance.sender.location.code,
+                    'direccionCompletaEmbalador': instance.sender.address.full_address
+                }
+            )
+
         logger.debug(payload)
         return payload
 
